@@ -105,7 +105,7 @@ $lang = array_merge($lang, array(
 	'BOARD_BAN_REASON'		=> 'Yasaklama için belirlenen sebep: <strong>%s</strong>',
 	'BOARD_BAN_TIME'		=> '<strong>%1$s</strong> zamanına kadar bu mesaj panosundan yasaklandınız.<br /><br />Daha fazla bilgi için lütfen %2$sMesaj Panosu Yöneticisi%3$s ile iletişime geçin.',
 	'BOARD_DISABLE'			=> 'Üzgünüz fakat bu mesaj panosu şimdilik kullanılamıyor.',
-	'BOARD_DISABLED'			=> 'Bu mesaj panosu şimdilik kapalı.',
+	'BOARD_DISABLED'			=> 'Bu mesaj panosu şu an kapalı durumda.',
 	'BOARD_UNAVAILABLE'		=> 'Üzgünüz fakat bu mesaj panosu geçici olarak kullanılamıyor, lütfen bir kaç dakika sonra tekrar deneyin.',
 	'BROWSING_FORUM'      => 'Bu forumu gezen kullanıcılar: %1$s',
 	'BROWSING_FORUM_GUEST'	=> 'Bu forumu gezen kullanıcılar: %1$s ve %2$d misafir',
@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'  => 'Yeni bir mesaj oluşturacağınız zaman bir konu belirlemelisiniz.',
 	'ENABLED'			=> 'Açık',
 	'ENCLOSURE'			=> 'Çevir',
+	'ENTER_USERNAME'					=> 'Kullanıcı adı girin',
 	'ERR_CHANGING_DIRECTORY'			=> 'Dizin değiştirilemiyor.',
 	'ERR_CONNECTING_SERVER'				=> 'Sunucuya bağlanırken hata oluştu.',
 	'ERR_JAB_AUTH'                  => 'Jabber sunucusunda erişim izni verilmedi.',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Forum kurallarını görüntülemek için lütfen buraya tıklayın',
 	'FROM'					=> 'kısım',
 	'FSOCK_DISABLED'		=> 'İşlem tamamlanamadı, çünkü <var>fsockopen</var> fonksiyonu kapatıldı ya da mevcut sunucu sorgusu bulunamadı.',
+	'FSOCK_TIMEOUT'			=> 'Ağ akışı okunurken bir zaman aşımı oluştu.',
 
 	'FTP_FSOCK_HOST'					=> 'FTP sunucusu',
 	'FTP_FSOCK_HOST_EXPLAIN'			=> 'Sitenize bağlanmak için kullandığınız FTP sunucusu.',
@@ -648,6 +650,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> okunmayan mesaj',
    	'UNREAD_POST'         => 'Okunmamış mesaj',
    	'UNREAD_POSTS'         => 'Okunmamış mesaj var',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Bu forumdan aboneliğinizi kaldırmak istediğinize emin misiniz?',
+	'UNWATCH_FORUM_DETAILED'	=> '“%s” adlı forumdan aboneliğinizi kaldırmak istediğinize emin misiniz?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Bu başlıktan aboneliğinizi kaldırmak istediğinize emin misiniz?',
+	'UNWATCH_TOPIC_DETAILED'	=> '“%s” konulu başlıktan aboneliğinizi kaldırmak istediğinize emin misiniz?',	
 	'UNWATCHED_FORUMS'		=> 'Seçilen forumlara abone olmadınız.',
 	'UNWATCHED_TOPICS'		=> 'Seçilen başlıklara abone olmadınız.',
 	'UNWATCHED_FORUMS_TOPICS'   => 'Seçilen girdilere abone olmadınız.',
@@ -695,6 +701,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Uyarılar',
 	'WARN_USER'			=> 'Kullanıcıya uyarı ver',
+	'WATCH_FORUM_CONFIRM'	=> 'Bu foruma abone olmak istediğinize emin misiniz?',
+	'WATCH_FORUM_DETAILED'	=> '“%s” adlı foruma abone olmak istediğinize emin misiniz?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Bu başlığa abone olmak istediğinize emin misiniz?',
+	'WATCH_TOPIC_DETAILED'	=> '“%s” konulu başlığa abone olmak istediğinize emin misiniz?',
 	'WELCOME_SUBJECT'	=> '%s forumlarına hoşgeldiniz',
 	'WEBSITE'			=> 'Web sitesi',
 	'WHOIS'				=> 'Kimdir',
